"""Force (REVIEW)
"""
from math import pi, exp
from util import _read_csv_data, _Iterate, _Interpolate, _OutOfRangeError






def torque(power:float, rpm_pulley:float):
    """Torque on the pulley
    :param power: power of the system, hp
    :type power: float
    :param rpm_pulley: rotational speed of the pulley, rpm
    :type rpm_pulley: float
    :return: torque of the pulley in kgf*m
    :rtype: float
    """
    return (2250*power)/(pi*rpm_pulley)


def _contact_arc_rad(factor:float):
    """Searches and _Interpolates a factor on a csv data table
    :param factor: factor (D-d)/Ca
    :type factor: float
    :return: angle of the contact between v-belt and pulley, rad
    :rtype: float
    """
    last_factor = 0
    last_contact_arc = 180
    for line in _read_csv_data('fcac_contact_arc'):
        if line['factor'] == factor:
            contact_arc = line['contact_arc']
            return (pi*contact_arc/180)
        elif last_factor < factor < line['factor']:
            contact_arc = _interpol(factor, last_factor, line['factor'], last_contact_arc, line['contact_arc'])
            return (pi*contact_arc/180)
        last_factor = line['factor']
        last_contact_arc = line['contact_arc']
    raise _OutOfRangeError('Value out of range for these parameters')


def _fric_coef(belt_material:str='rubber', pulley_material:str='steel'):
    """Select coefficient of friction from csv data table
    :param belt_material: material of the belt, select between `polyurethane`, `nylon` and `rubber`, defaults to `rubber`
    :type belt_material: str, optional
    :param pulley_material: material of the pulley, select between `steel` and `aluminum`, defaults to `steel`
    :type pulley_material: str, optional
    :return: friction coefficient
    :rtype: float
    """
    for line in _read_csv_data('fric_coef'):
        if line['belt_material'] == belt_material:
            if line['pulley_material'] == pulley_material:
                return line['fric_coef']
    raise _OutOfRangeError('Value out of range for these parameters')


def _forces(m_torque:float, diam_driving:float, diam_driven:float, corr_distance_pulleys:float, belt_material:str='rubber', pulley_material:str='steel'):
    """Main forces of the pulley/belt system
    :param m_torque: torque of the system, kgf*m
    :type m_torque: float
    :param diam_driving: diameter of the driving pulley, mm
    :type diam_driving: float
    :param diam_driven: diameter of the driven pulley, mm
    :type diam_driven: float
    :param corr_distance_pulleys: corrected distance between the pulley's center, mm
    :type corr_distance_pulleys: float
    :param belt_material: material of the belt, select between `polyurethane`, `nylon` and `rubber`, defaults to `rubber`
    :type belt_material: str, optional
    :param pulley_material: material of the pulley, select between `steel` and `aluminum`, defaults to `steel`
    :type pulley_material: str, optional
    :return: list of three main force values, f_0, f_1 and f_z, all in kgf
    :rtype: list
    """
    f_u = (m_torque * 9.81)/(diam_driving/(2 * 1000))
    factor_contact = (max(diam_driving, diam_driven) - min(diam_driving, diam_driven))/corr_distance_pulleys
    carc_rad = _contact_arc_rad(factor_contact)
    mu = _fric_coef(belt_material, pulley_material)    
    f_0 = (f_u/(exp(mu*carc_rad)-1))/9.81
    f_1 = (f_u*(exp(mu*carc_rad)/(exp(mu * carc_rad)-1)))/9.81
    f_z = (f_u*(exp(mu*carc_rad)+1)/(exp(mu * carc_rad)-1))/9.81
    return [f_0, f_1, f_z]


def axle(m_torque:float, diam_driving:float, diam_driven:float, corr_distance_pulleys:float, belt_material:str='rubber', pulley_material:str='steel'):
    """Axle force on the pulley
    :param m_torque: torque of the system, kgf*m
    :type m_torque: float
    :param diam_driving: diameter of the driving pulley, mm
    :type diam_driving: float
    :param diam_driven: diameter of the driven pulley, mm
    :type diam_driven: float
    :param corr_distance_pulleys: corrected distance between the pulley's center, mm
    :type corr_distance_pulleys: float
    :param belt_material: material of the belt, select between `polyurethane`, `nylon` and `rubber`, defaults to `rubber`
    :type belt_material: str, optional
    :param pulley_material: material of the pulley, select between `steel` and `aluminum`, defaults to `steel`
    :type pulley_material: str, optional
    :return: axle force on the pulley, kgf
    :rtype: float
    """
    return (_forces(m_torque, diam_driving, diam_driven, corr_distance_pulleys, belt_material, pulley_material)[2])


def tangential(m_torque:float, diam_driving:float, diam_driven:float, corr_distance_pulleys:float, belt_material:str='rubber', pulley_material:str='steel'):
    """Tangential force on the v-belt
    :param m_torque: torque of the system, kgf*m
    :type m_torque: float
    :param diam_driving: diameter of the driving pulley, mm
    :type diam_driving: float
    :param diam_driven: diameter of the driven pulley, mm
    :type diam_driven: float
    :param corr_distance_pulleys: corrected distance between the pulley's center, mm
    :type corr_distance_pulleys: float
    :param belt_material: material of the belt, select between `polyurethane`, `nylon` and `rubber`, defaults to `rubber`
    :type belt_material: str, optional
    :param pulley_material: material of the pulley, select between `steel` and `aluminum`, defaults to `steel`
    :type pulley_material: str, optional
    :return: tangential force on the pulley, kgf
    :rtype: float
    """
    ft_1, ft_2 = _forces(m_torque, diam_driving, diam_driven, corr_distance_pulleys, belt_material, pulley_material)[:2]
    return (ft_1 - ft_2)


from util import _Iterate, _OutOfRangeError


class EstPower():
    r"""EstPower class calculates the estimated power to run the pulley system.

    Parameters
    ----------
    engine_power : float
        Engine power, [hp]
    drive_group : int
        Engine group classifier, [-]
    machine_group : int
        Machine group classifier, [-]
    hours_service : float
        Amount of hours per day that the system is on, [h]
    
    Attributes
    ----------
    service_factor : float
        Service factor of the system
    
    Notes
    -----
    The service factor data [#]_ is available online.

    Examples
    --------
    >>> est_power = vbelts.power.EstPower(2, 1, 1, 4)
    >>> est_power.calc()
    2
    >>> est_power2 = vbelts.power.EstPower(2, 2, 4, 18)
    >>> est_power2.calc()
    3.6

    References
    ----------
    .. [#] Megadyne. 2016."V-BELTS: Rubber V-belts", **Vermeire webshop**. Accessed September 14, 2020, http://shop.vermeire.com/inc/Doc/courroies/megadyne/2016/v_belts_jan_2016.pdf
    """
    def __init__(self, engine_power:float, drive_group:int, machine_group:int, hours_service:float):
        self.engine_power = engine_power
        self.drive_group = drive_group
        self.machine_group = machine_group
        self.hours_service = hours_service
        self._sf()
    

    def _sf(self):
        r"""Method selects and calculates the service factor.
        """
        # calculate service_factor partial
        if self.machine_group == 1:
            if 0 < self.hours_service <= 5:
                sf_part = 1.0
            elif 5 < self.hours_service <= 10:
                sf_part = 1.1
            elif 10 < self.hours_service <= 24:
                sf_part = 1.2
        elif self.machine_group == 2:
            if 0 < self.hours_service <= 5:
                sf_part = 1.1
            elif 5 < self.hours_service <= 10:
                sf_part = 1.2
            elif 10 < self.hours_service <= 24:
                sf_part = 1.3
        elif self.machine_group == 3:
            if 0 < self.hours_service <= 5:
                sf_part = 1.2
            elif 5 < self.hours_service <= 10:
                sf_part = 1.3
            elif 10 < self.hours_service <= 24:
                sf_part = 1.4
        elif self.machine_group == 4:
            if 0 < self.hours_service <= 5:
                sf_part = 1.3
            elif 5 < self.hours_service <= 10:
                sf_part = 1.4
            elif 10 < self.hours_service <= 24:
                sf_part = 1.5
        # calculate service_factor additional and final
        if self.machine_group == 1 and self.drive_group == 2:
            result = sf_part + 0.1
        elif self.machine_group == 2 and self.drive_group == 2:
            result = sf_part + 0.1
        elif self.machine_group == 3 and self.drive_group == 2:
            if sf_part == 1.4:
                result = sf_part + 0.1
            else:
                result = sf_part + 0.2
        elif self.machine_group == 4 and self.drive_group == 2:
            if sf_part == 1.4:
                result = sf_part + 0.2
            else:
                result = sf_part + 0.3
        else:
            result = sf_part
        self._service_factor = round(result,1)

    
    def calc(self):
        r"""Estimated power to run the pulley system.

        Returns
        -------
        pp : float
            Estimated power, [hp]
        
        Notes
        -----
        The equation to calculate the estimated power, using the engine power `P_{engine}` and the service factor `F_s`:

        .. math::
            P_p = P_{engine} \cdot F_s
        """
        pp = self.engine_power * self._service_factor
        return pp


class TransPower():
    """TransPower class calculates the quantity of belts needed to ensure the power of the system.

    Parameters
    ----------
    vbelt_model : str
        Model of the v-belt, [-]
    vbelt_profile : str
        Profile of the v-belt, [-]
    vbelt_type : str
        Type of the v-belt, [-]
    est_power : float
        Estimated power, [hp]
    gear_ratio : float
        Pulley system gear ratio, [-]
    belt_length_corr : float
        Corrected belt length, [-]
    min_diam : float
        Smallest pulley, [mm]
    maj_diam : float
        Largest pulley, [mm]
    rpm : float
        Fastest axle rotation speed, [rpm]
    
    Notes
    -----
    All the information [#]_ is available online. The valid entries for `vbelt_model`, `vbelt_profile` and `vbelt_type` are in the :ref:`Model Profile <vbelt_model_profile>` and in the :ref:`Types <vbelt_types>` of the data section.

    Examples
    --------
    >>> trans_power = vbelts.power.TransPower('HiPower', 'a', 'A-32', 2, 130/240, 850, 130, 240, 1750)
    >>> trans_power.calc()
    0.5060451558976288

    References
    ----------
    .. [#] Claudino Alves, Claudemir. "Transmissão por Correias - Dimensionamento Atividade 2". **Fatec Itaquera**. Accessed September 16, 2020, http://claudemiralves.weebly.com/uploads/3/8/6/2/3862918/dimen._de_correias.pdf.
    """
    def __init__(self, vbelt_model:str, vbelt_profile:str, vbelt_type:str, est_power:float, gear_ratio:float, belt_length_corr:float, min_diam:float, maj_diam:float, rpm:float, iterator:_Iterate=_Iterate):
        self.b_model = vbelt_model
        self.b_profile = vbelt_profile
        self.b_type = vbelt_type
        self.est_power = est_power
        self.gear_ratio = gear_ratio
        self.l_corr = belt_length_corr
        self.min_diam = min_diam
        self.maj_diam = maj_diam
        self.rpm = rpm
        self.iterator = iterator
        self._fc_length()
        self._basic()
        self._additional()
        self._fc_arc()
    

    def _fc_length(self):
        """Selects the appropriate correction factor for belt length."""
        filename_fcc = f'{self.b_model}_fcc'
        for line in self.iterator(filename_fcc).read():
            if line['type'] == self.b_type:
                self._fcc = float(line['fcc'])
    

    def _basic(self):
        """Select the basic power transmitted by belt unit."""
        filename_pb = f'{self.b_model}_{self.b_profile}_pb'
        temp_result, adjust = self.iterator(filename_pb, 'diameter', 'rpm', 'power_b').three_rows(self.min_diam, self.rpm)
        # result adjusting for interpolation
        if adjust:
            if 0.3 < temp_result <= 1:
                self._p_basic = temp_result - 0.25
            elif 1 < temp_result <= 10:
                self._p_basic = temp_result - 0.5
            elif 10 < temp_result <= 120:
                self._p_basic = temp_result - 2.5
        else:
            self.p_basic = temp_result
    

    def _additional(self):
        """Selects the additional power transmitted by belt unit."""
        filename_pa = f'{self.b_model}_{self.b_profile}_pa'
        # checking if gear_ratio is below one and adjust
        if self.gear_ratio < 1:
            gear_ratio_corr = 1/self.gear_ratio
        else:
            gear_ratio_corr = self.gear_ratio
        self._p_add = self.iterator(filename_pa, 'gr_low', 'gr_high', 'rpm', 'power_a').four_rows(gear_ratio_corr, self.rpm)


    def _fc_arc(self):
        """Selects the appropriate correction factor for contact arc."""
        factor = (self.maj_diam - self.min_diam) / self.l_corr
        self._fcac = self.iterator('fcac_contact_arc', 'factor', 'contact_arc', 'fcac').three_rows_choose(factor, 3)


    def belt_qty(self):
        r"""Number of v-belts needed to transmit the estimated power.

        Returns
        -------
        b_qty : float
            Quantity of v-belts, [-]
        

        Notes
        -----
        Before calculate the belt quantity, the transmitted power `P_t` in horse-power has to be calculated [#]_ by:

        .. math::
            P_t = (P_b + P_a) \cdot f_{cc} \cdot f_{cac}

        Where `P_b` is the basic power transmitted, `P_a` is the additional power transmitted, `f_{cc}` is the length correction factor and `f_{cac}` is the contact arc correction factor.
        Then, the belt quantity is calculated by:

        .. math::
            N_{v-belt} = \frac{P_{estimated}}{P_t}

        References
        ----------
        .. [#] Claudino Alves, Claudemir. "Transmissão por Correias - Dimensionamento Atividade 2". **Fatec Itaquera**. Accessed September 16, 2020, http://claudemiralves.weebly.com/uploads/3/8/6/2/3862918/dimen._de_correias.pdf.
        """
        belt_transmission_capacity = (self._p_basic + self._p_add) * self._fcc * self._fcac
        return self.est_power / belt_transmission_capacity



# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os, sys
sys.path.insert(0, os.path.abspath('../..'))


# -- Project information -----------------------------------------------------

project = 'vbelts'
copyright = '2020, Glademir Karpinski Junior, Hector Balke Nodari'
author = 'Glademir Karpinski Junior, Hector Balke Nodari'

# The full version, including alpha/beta/rc tags
release = '0.3.3-beta'

master_doc = 'index'

# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = ['sphinx.ext.autodoc', 'sphinx.ext.napoleon']

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#

import sphinx_rtd_theme

html_theme = 'sphinx_rtd_theme'

html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['']

# Napoleon settings
napoleon_google_docstring = True
napoleon_numpy_docstring = True
napoleon_include_init_with_doc = False
napoleon_include_private_with_doc = False
napoleon_include_special_with_doc = True
napoleon_use_admonition_for_examples = False
napoleon_use_admonition_for_notes = False
napoleon_use_admonition_for_references = False
napoleon_use_ivar = True
napoleon_use_param = True
napoleon_use_rtype = True
napoleon_type_aliases = None


# -*- coding: utf-8 -*-
"""Utilities for v-belt dimensioning.
Copyright (C) 2020 Glademir Karpinski Junior <gkarpinskijr@gmail.com>,
Hector Balke Nodari <hectornodari@gmail.com>

Redistribution and use in source and binary forms, with or without modification, are permitted provided
that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this list of conditions and
the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
the following disclaimer in the documentation and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or
promote products derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

vbelts provides functions that allow the computation of complex factors in v-belt dimensioning."""

# import os

import belt
import length
import util
import power
import speed
# from . import force
import pulley

# from . belt import *
# from . length import *
# from . util import *
# from . power import *
# from . speed import *
# # # from .force import *
# from . pulley import *

__all__ = ['belt', 'length', 'util', 'power', 'speed', 'pulley']

# try:
#     vbelts_dir = os.path.dirname(__file__)
#     vbelts_data_dir = os.path.join(vbelts_dir, 'data')
# except:
#     pass



from util import _Interpolate, _Iterate, _OutOfRangeError
from abc import ABC

h_factor = {0:0, 0.02:0.01, 0.04:0.02, 0.06:0.03, 0.08:0.04, 0.1:0.05, 0.12:0.06, 0.14:0.07, 0.16:0.08, 0.18:0.09, 0.2:0.1, 0.21:0.11, 0.23:0.12, 0.25:0.13, 0.27:0.14, 0.29:0.15, 0.3:0.16, 0.32:0.17, 0.34:0.18, 0.35:0.19, 0.37:0.2, 0.39:0.21, 0.4:0.22, 0.41:0.23, 0.43:0.24, 0.44:0.25, 0.46:0.26, 0.47:0.27, 0.48:0.28, 0.5:0.29, 0.51:0.3}


class _Dist(ABC):
    """Abstract class holding private methods to calculate distance properties"""
    def __init__(self, min_diam:float, maj_diam:float):
        self.min_diam = min_diam
        self.maj_diam = maj_diam
        self._c_uc()
        self._l_uc()

    
    def _c_uc(self):
        """Uncorrected center distance"""
        self.center_uncorr = (3 * self.min_diam + self.maj_diam)/2
    

    def _l_uc(self):
        """Uncorrected belt length"""
        self.l_uncorr = 2 * self.center_uncorr + 1.57 * (self.maj_diam + self.min_diam) + ((self.maj_diam - self.min_diam)**2/(4 * self.center_uncorr))


class PulleyBelt(_Dist):
    r"""PulleyBelt class calculates the corrected belt length and the corrected center distance.

    Parameters
    ----------
    min_diam : float
        Smallest pulley, [mm]
    maj_diam : float
        Largest pulley, [mm]
    belt : str
        Belt model, [-]
    b_profile : str
        Belt profile, [-]
    
    Attributes
    ----------
    l_corr : float
        V-Belt corrected length, [mm]
    b_type : str
        V-Belt selected type, [-]
    c_corr : float
        Pulley corrected center length, [mm]


    Notes
    -----
    All the information [#]_ is available online. The valid entries for `belt` and `b_profile` are in the :ref:`Model Profile <vbelt_model_profile>` data section.

    Examples
    --------
    >>> dist = vbelts.length.PulleyBelt(120, 240, 'HiPower', 'a')
    >>> dist.l_c()
    (1200, 'A-46')
    >>> dist.c_c()
    310.72814411208714

    References
    ----------
    .. [#] Claudino Alves, Claudemir. "Transmissão por Correias - Dimensionamento Atividade 2". **Fatec Itaquera**. Accessed September 16, 2020, http://claudemiralves.weebly.com/uploads/3/8/6/2/3862918/dimen._de_correias.pdf.

    """
    def __init__(self, min_diam:float, maj_diam:float, belt:str, b_profile:str, iterator:_Iterate=_Iterate, interpol:_Interpolate=_Interpolate):  # inject the objects inside the class
        super().__init__(min_diam, maj_diam)
        self.belt = belt
        self.b_profile = b_profile
        self.iterator = iterator
        self.interpol = interpol
        self.corr_dict = h_factor
        self._l_c()
        self._l_a()
        self._h_factor()


    def _l_c(self):
        """Calculates the corrected v-belt length and type."""
        self.l_corr, self.b_type = self.iterator(f'{self.belt}_length', 'profile', 'length', 'type').belt_type(self.b_profile, self.l_uncorr)
    

    def l_c(self):
        r"""Belt commercial length and v-belt type.

        Returns
        -------
        result : tuple
            Contains the l_corr and b_type in tuple data form, [-]
        l_corr : float
            Length of the commercial belt chosen, [mm]
        b_type : str
            Commercial v-belt type, [-]

        Notes
        -----
        The return product is a tuple with both values.

        The calculation and selection of the type depends on a number of secundary factors, all available online [#]_.
        First, the pulley center distance uncorrected, `C`, is calculated based on the major `D` and minor `d` pulley diameters:

        .. math::
            C = \frac{3 \cdot d + D}{2}

        Second, the uncorrected length of the belt, `l` is calculated:

        .. math::
            l = 2 \cdot C + 1.57 \cdot (D + d) + \frac{(D - d)**2}{4 \cdot C}

        Third, the corrected commercial length of the v-belt, `l_c` is selected based on the v-belt model and uncorrected length `l`. Please see the :ref:`Data <vbelt_length_data>` for all models in the module.

        References
        ----------
        .. [#] Claudino Alves, Claudemir. "Transmissão por Correias - Dimensionamento Atividade 2". **Fatec Itaquera**. Accessed September 16, 2020, http://claudemiralves.weebly.com/uploads/3/8/6/2/3862918/dimen._de_correias.pdf.
        """
        return (self.l_corr, self.b_type)
    
    
    def _h_factor(self):
        """Calculates and selects the appropriate correction factor for the center distance between pulleys."""
        adim_factor = (self.maj_diam - self.min_diam)/self._l_adj
        for key in self.corr_dict:
            last_factor = 0
            if key == adim_factor:
                self._h = self.corr_dict.get(key)
            elif key > adim_factor:
                self._h = self.interpol(adim_factor, last_factor, key, self.corr_dict.get(last_factor), self.corr_dict.get(key)).y_data()
            last_factor = key
        if self._h is None:
            raise _OutOfRangeError('Value out of range for these parameters')


    def _l_a(self):
        """Corrected belt length for commercial belts."""
        self._l_adj = self.l_corr - 1.57 * (self.maj_diam + self.min_diam)
    

    def c_c(self):
        r"""Corrected pulley center distance for commercial belts.

        Returns
        -------
        c_corr : float
            Corrected center distance between the pulleys, [mm]
        
        Notes
        -----
        The calculation [#]_ demands the adjusted length of the belt, `l_a`, the major pulley diameter `D` and the minor pulley diameter `d`.
        First, the ratio below is calculated:

        .. math::
            \frac{D-d}{l_a}

        Second, from a list of correction factors for center distances, `h` is selected. Please see the :ref:`Data section <vbelt_h_factor_data>` for the complete list.
        Third and finally, the adjusted center distance is defined:

        .. math::
            C_c = \frac{l_a - h \cdot (D - d)}{2}

        References
        ----------
         .. [#] Claudino Alves, Claudemir. "Transmissão por Correias - Dimensionamento Atividade 2". **Fatec Itaquera**. Accessed September 16, 2020, http://claudemiralves.weebly.com/uploads/3/8/6/2/3862918/dimen._de_correias.pdf.
        """
        self.c_corr = (self._l_adj - self._h *(self.maj_diam - self.min_diam))/2
        return self.c_corr